# esp-idf-kconfig

The ```esp-idf-kconfig``` package is part of the [ESP-IDF](https://github.com/espressif/esp-idf) SDK for Espressif products and is automatically installed.

It is responsible for enabling project configuration using the ```kconfig``` language, providing IDE support for configuration and configuration documentation generation.

For more information about how it works go to the [documentation](https://docs.espressif.com/projects/esp-idf-kconfig/en/latest/index.html).

## Contributing

Contributions are welcome!

Detailed guide on how to contribute can be found in the [Developer Guide](https://docs.espressif.com/projects/esp-idf-kconfig/en/latest/developer-guide/contributing.html)

## Reporting issues

If you find a bug or have a feature request, please open an issue on GitHub. But before doing so, please check if a similar issue ticket exists. If you are reporting a bug, please provide as much information as possible, e.g. the version of the package, the version of Python you are using, the steps to reproduce the bug, etc.

Before reporting a bug, please check:

- Differences between esp-idf-kconfig and kconfiglib, see [list of differences](https://docs.espressif.com/projects/esp-idf-kconfig/en/latest/kconfiglib/differences.html).
- Already reported issues, see [GitHub Issues](https://github.com/espressif/esp-idf-kconfig/issues?q=is%3Aissue).
